==> freesewing-0.22.1.tgz: package/README.md <==
<p align="center">
  <a title="Go to freesewing.org" href="https://freesewing.org/"><img src="https://freesewing.org/img/logo/black.svg" align="center" width="150px" alt="Freesewing logo"/></a>
</p>
<h4 align="center"><em>&nbsp;<a title="Go to freesewing.org" href="https://freesewing.org/">freesewing</a></em>
<br><sup>a library for made-to-measure sewing patterns</sup>
</h4>
<p align="center">
  <a href="https://travis-ci.org/freesewing/freesewing"><img src="https://badgen.net/travis/freesewing/freesewing/master" alt="Travis build"></a>
  <a href="https://www.npmjs.com/package/freesewing"><img src="https://badgen.net/npm/v/freesewing" alt="Version"></a>
  <a href="https://www.npmjs.com/package/freesewing"><img src="https://badgen.net/npm/license/freesewing" alt="License"></a>
  <a href="https://codecov.io/gh/freesewing/freesewing"><img src="https://badgen.net/codecov/c/github/freesewing/freesewing/master" alt="Code coverage"></a>
  <a href="https://deepscan.io/dashboard#view=project&pid=2993&bid=23256"><img src="https://deepscan.io/api/projects/2993/branches/23256/badge/grade.svg" alt="DeepScan grade"></a>
  <a href="https://gitter.im/freesewing/freesewing"><img src="https://badgen.net/badge/chat/on%20Gitter/cyan" alt="Chat on Gitter"></a>
  <a href="https://freesewing.org/patrons/join"><img src="https://badgen.net/badge/become/a%20Patron/FF5B77" alt="Become a Patron"></a>
</p>

# freesewing

[Freesewing](https://freesewing.org/) is an open source platform for made-to-measure sewing pattern.  
This is our core library.

## Links

 - 💻 Website: [freesewing.org](https://freesewing.org)
 - 💬 Chat: [Gitter](https://gitter.im/freesewing/freesewing)
 - 🐦 Twitter: [@freesewing_org](https://twitter.com/freesewing_org)
 - 📷 Instagram: [@freesewing_org](https://instagram.com/freesewing_org)
 
## Features

- Parametric design of sewing patterns
- Modular design with support for [plugins](https://github.com/freesewing/plugins)
- Auto-layout of pattern parts
- Auto-offset of paths for seam allowance
- Support for paperless patterns (with [our theme plugin](https://github.com/freesewing/plugin-theme))
- Sampling of options, a single measurement, or across models
- Renders to SVG
- Run in the browser as well as on the server with Node.js

## Getting started

This repository is a rewrite of [freesewing/core](https://github.com/freesewing/core) in JavaScript.  

It is an ongoing project, and not ready for prime-time yet. Watch this space.

==> freesewing-0.31.0.tgz: package/README.md <==
<p align="center">
  <a title="Go to freesewing.org" href="https://freesewing.org/"><img src="https://freesewing.org/img/logo/black.svg" align="center" width="150px" alt="Freesewing logo"/></a>
</p>
<h4 align="center"><em>&nbsp;<a title="Go to freesewing.org" href="https://freesewing.org/">freesewing</a></em>
<br><sup>a library for made-to-measure sewing patterns</sup>
</h4>
<p align="center">
  <a href="https://travis-ci.org/freesewing/freesewing"><img src="https://badgen.net/travis/freesewing/freesewing/master" alt="Travis build"></a>
  <a href="https://www.npmjs.com/package/freesewing"><img src="https://badgen.net/npm/v/freesewing" alt="Version"></a>
  <a href="https://www.npmjs.com/package/freesewing"><img src="https://badgen.net/npm/license/freesewing" alt="License"></a>
  <a href="https://codecov.io/gh/freesewing/freesewing"><img src="https://badgen.net/codecov/c/github/freesewing/freesewing/master" alt="Code coverage"></a>
  <a href="https://deepscan.io/dashboard#view=project&pid=2993&bid=23256"><img src="https://deepscan.io/api/projects/2993/branches/23256/badge/grade.svg" alt="DeepScan grade"></a>
  <a href="https://gitter.im/freesewing/freesewing"><img src="https://badgen.net/badge/chat/on%20Gitter/cyan" alt="Chat on Gitter"></a>
  <a href="https://freesewing.org/patrons/join"><img src="https://badgen.net/badge/become/a%20Patron/FF5B77" alt="Become a Patron"></a>
</p>

# freesewing

[Freesewing](https://freesewing.org/) is an open source platform for made-to-measure sewing patterns.  

Try [the online demo](https://beta.freesewing.org/en/demo/) to *get it*.

## Links

 - 💻 Website: [freesewing.org](https://freesewing.org)
 - 💬 Chat: [Gitter](https://gitter.im/freesewing/freesewing)
 - 🐦 Twitter: [@freesewing_org](https://twitter.com/freesewing_org)
 - 📷 Instagram: [@freesewing_org](https://instagram.com/freesewing_org)
 
## Features

- Parametric design of sewing patterns
- Modular design with support for [plugins](https://github.com/freesewing/plugins)
- Auto-layout of pattern parts
- Auto-offset of paths for seam allowance
- Support for paperless patterns (with [our theme plugin](https://github.com/freesewing/plugin-theme))
- Sampling of options, a single measurement, or across models
- Renders to SVG
- Run in the browser as well as on the server with Node.js

## Getting started

This repository is a rewrite of [freesewing/core](https://github.com/freesewing/core) in JavaScript.  

It is an ongoing project, and not ready for prime-time yet. Watch this space.
